@@ -7,7 +7,7 @@ use Exporter;
 our @ISA=qw(Exporter);
 our @EXPORT=qw(distance midpoint slope gradient);
 
-our $VERSION='1.0.7';
+our $VERSION='1.0.8';
 our $LIBRARY=__PACKAGE__;
 
 sub distance(x1,y1,x2,y2){return sqrt((x2-x1)**2+(y2-y1)**2)}
@@ -27,7 +27,7 @@ Math::CooGeo - Coordinate geometry library for Perl.
 
 =head1 VERSION
 
-Version 1.0.7
+Version 1.0.8
 
 =head1 DESCRIPTION
 
@@ -133,7 +133,7 @@ L<GitHub|https://github.com/DeBos99/Math-CooGeo/issues>
 
 =item *
 
-Discord: DeBos#3292
+L<@DeBos99|https://t.me/DeBos99>
 
 =item *
 
